To do list
==========

- `Alternative syntax for blocks with decorator and context manager
  <https://bitbucket.org/fluiddyn/fluidpythran/issues/29>`_

- Type hints: `Shape <https://bitbucket.org/fluiddyn/fluidpythran/issues/12>`_

Inline to do items
------------------

.. todolist::
